@@ -20,7 +20,7 @@ SORT_DIR_VALUES = ('asc', 'desc')
 
 SHARE_SORT_KEY_VALUES = (
     'id', 'status', 'size', 'host', 'share_proto',
-    'availability_zone',
+    'availability_zone_id', 'availability_zone',
     'user_id', 'project_id',
     'created_at', 'updated_at',
     'display_name', 'name',
@@ -68,6 +68,40 @@ SHARE_GROUP_SNAPSHOT_SORT_KEY_VALUES = (
     'share_group_id',
 )
 
+SHARE_TRANSFER_SORT_KEY_VALUES = (
+    'id',
+    'resource_type',
+    'resource_id',
+    'name',
+    'source_project_id',
+    'destination_project_id',
+    'created_at',
+    'expires_at',
+)
+
+RESOURCE_LOCK_SORT_KEY_VALUES = (
+    'id',
+    'created_at',
+    'updated_at',
+    'resource_id',
+    'resource_type',
+    'resource_action'
+    'lock_reason',
+)
+
+BACKUP_SORT_KEY_VALUES = (
+    'id',
+    'status',
+    'size',
+    'share_id',
+    'progress',
+    'restore_progress',
+    'name',
+    'host',
+    'topic',
+    'project_id',
+)
+
 TASK_STATE_MIGRATION_SUCCESS = 'migration_success'
 TASK_STATE_MIGRATION_ERROR = 'migration_error'
 TASK_STATE_MIGRATION_CANCELLED = 'migration_cancelled'
@@ -103,13 +137,21 @@ SNAPSHOT_SUPPORT = 'snapshot_support'
 CREATE_SHARE_FROM_SNAPSHOT_SUPPORT = 'create_share_from_snapshot_support'
 REVERT_TO_SNAPSHOT_SUPPORT = 'revert_to_snapshot_support'
 MOUNT_SNAPSHOT_SUPPORT = 'mount_snapshot_support'
+CONSISTENT_SNAPSHOT_SUPPORT = 'consistent_snapshot_support'
 
 BOOL_SPECS = (
     SNAPSHOT_SUPPORT,
     CREATE_SHARE_FROM_SNAPSHOT_SUPPORT,
     REVERT_TO_SNAPSHOT_SUPPORT,
-    MOUNT_SNAPSHOT_SUPPORT
+    MOUNT_SNAPSHOT_SUPPORT,
+)
+
+# share group types
+GROUP_BOOL_SPECS = (
+    CONSISTENT_SNAPSHOT_SUPPORT,
 )
 
 REPLICA_GRADUATION_VERSION = '2.56'
 REPLICA_PRE_GRADUATION_VERSION = '2.55'
+SHARE_TRANSFER_VERSION = '2.77'
+RESOURCE_LOCK_VERSION = '2.81'
