@@ -145,7 +145,7 @@ class OSCClientTestBase(base.ClientTestBase):
                      snapshot_id=None, properties=None, share_network=None,
                      description=None, public=False, share_type=None,
                      availability_zone=None, share_group=None,
-                     add_cleanup=True, client=None,
+                     add_cleanup=True, client=None, wait=None,
                      wait_for_status='available'):
 
         name = name or data_utils.rand_name('autotest_share_name')
@@ -174,6 +174,8 @@ class OSCClientTestBase(base.ClientTestBase):
             cmd = cmd + ' --availability-zone %s' % availability_zone
         if share_group:
             cmd = cmd + ' --share-group %s' % share_group
+        if wait:
+            cmd = cmd + ' --wait'
 
         share_object = self.dict_result('share', cmd, client=client)
         self._wait_for_object_status(
@@ -259,7 +261,11 @@ class OSCClientTestBase(base.ClientTestBase):
 
     def create_share_access_rule(self, share, access_type,
                                  access_to, properties=None,
-                                 access_level=None, wait=False):
+                                 access_level=None, wait=False,
+                                 lock_visibility=False,
+                                 lock_deletion=False,
+                                 lock_reason=None,
+                                 add_cleanup=False):
         cmd = f'access create {share} {access_type} {access_to} '
 
         if access_level:
@@ -267,7 +273,13 @@ class OSCClientTestBase(base.ClientTestBase):
         if properties:
             cmd += f'--properties {properties} '
         if wait:
-            cmd += f'--wait'
+            cmd += '--wait '
+        if lock_visibility:
+            cmd += '--lock-visibility '
+        if lock_deletion:
+            cmd += '--lock-deletion '
+        if lock_reason:
+            cmd += f'--lock-reason {lock_reason}'
 
         access_rule = self.dict_result('share', cmd)
 
@@ -302,6 +314,14 @@ class OSCClientTestBase(base.ClientTestBase):
 
         return snapshot_object
 
+    def create_share_transfer(self, share, name=None, client=None):
+
+        name = name or data_utils.rand_name('autotest_share_transfer_name')
+        cmd = (f'transfer create {share} --name {name} ')
+        transfer_object = self.dict_result('share', cmd, client=client)
+
+        return transfer_object
+
     def create_share_network(self, neutron_net_id=None,
                              neutron_subnet_id=None, name=None,
                              description=None, availability_zone=None,
@@ -404,7 +424,53 @@ class OSCClientTestBase(base.ClientTestBase):
         if availability_zone:
             cmd += f' --availability-zone {availability_zone}'
         if restart_check:
-            cmd += f' --restart-check'
+            cmd += ' --restart-check'
 
         check_result = self.dict_result('share', cmd)
         return check_result
+
+    def create_resource_lock(self, resource_id, resource_type='share',
+                             resource_action='delete', lock_reason=None,
+                             add_cleanup=True, client=None):
+
+        cmd = f'lock create {resource_id} {resource_type}'
+        cmd += f' --resource-action {resource_action}'
+
+        if lock_reason:
+            cmd += f' --reason "{lock_reason}"'
+
+        lock = self.dict_result('share', cmd, client=client)
+
+        if add_cleanup:
+            self.addCleanup(self.openstack,
+                            'share lock delete %s' % lock['id'],
+                            client=client)
+        return lock
+
+    def create_backup(self, share_id, name=None, description=None,
+                      backup_options=None, add_cleanup=True):
+
+        name = name or data_utils.rand_name('autotest_backup_name')
+
+        cmd = (f'backup create {share_id} ')
+
+        if name:
+            cmd += f' --name {name}'
+        if description:
+            cmd += f' --description {description}'
+        if backup_options:
+            options = ' --backup-options'
+            for key, value in backup_options.items():
+                options += f' {key}={value}'
+            cmd += options
+
+        backup_object = self.dict_result('share', cmd)
+        self._wait_for_object_status(
+            'share backup', backup_object['id'], 'available')
+
+        if add_cleanup:
+            self.addCleanup(
+                self.openstack,
+                f'share backup delete {backup_object["id"]} --wait')
+
+        return backup_object
