@@ -30,12 +30,14 @@ class FakeShareClient(object):
         self.auth_token = kwargs['token']
         self.management_url = kwargs['endpoint']
         self.shares = mock.Mock()
+        self.transfers = mock.Mock()
         self.share_access_rules = mock.Mock()
         self.share_groups = mock.Mock()
         self.share_types = mock.Mock()
         self.share_type_access = mock.Mock()
         self.quotas = mock.Mock()
         self.quota_classes = mock.Mock()
+        self.share_backups = mock.Mock()
         self.share_snapshots = mock.Mock()
         self.share_group_snapshots = mock.Mock()
         self.share_snapshot_export_locations = mock.Mock()
@@ -60,6 +62,7 @@ class FakeShareClient(object):
         self.share_group_types = mock.Mock()
         self.share_group_type_access = mock.Mock()
         self.share_servers = mock.Mock()
+        self.resource_locks = mock.Mock()
 
 
 class ManilaParseException(Exception):
@@ -136,6 +139,7 @@ class FakeShare(object):
             "revert_to_snapshot_support": False,
             "source_share_group_snapshot_member_id": None,
             "scheduler_hints": {},
+            "mount_point_name": None,
         }
 
         # Overwrite default attributes.
@@ -326,6 +330,7 @@ class FakeShareExportLocation(object):
             "id": "id-" + uuid.uuid4().hex,
             "is_admin_only": False,
             "preferred": False,
+            "properties": {},
             "updated_at": 'time-' + uuid.uuid4().hex,
         }
 
@@ -585,6 +590,64 @@ class FakeShareSnapshot(object):
         return share_snapshots
 
 
+class FakeShareTransfer(object):
+    """Fake a share transfer"""
+
+    @staticmethod
+    def create_one_transfer(attrs=None, methods=None):
+        """Create a fake share transfer
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :return:
+            A FakeResource object, with id, resource and so on
+        """
+
+        attrs = attrs or {}
+        methods = methods or {}
+        now_time = datetime.datetime.now()
+        delta_time = now_time + datetime.timedelta(minutes=5)
+
+        share_transfer = {
+            'accepted': 'False',
+            'auth_key': 'auth-key-' + uuid.uuid4().hex,
+            'created_at': now_time.isoformat(),
+            'destination_project_id': None,
+            'expires_at': delta_time.isoformat(),
+            'id': 'transfer-id-' + uuid.uuid4().hex,
+            'name': 'name-' + uuid.uuid4().hex,
+            'resource_id': 'resource-id-' + uuid.uuid4().hex,
+            'resource_type': 'share',
+            'source_project_id': 'source-project-id-' + uuid.uuid4().hex
+        }
+
+        share_transfer.update(attrs)
+        share_transfer = osc_fakes.FakeResource(info=copy.deepcopy(
+            share_transfer),
+            methods=methods,
+            loaded=True)
+        return share_transfer
+
+    @staticmethod
+    def create_share_transfers(attrs=None, count=2):
+        """Create multiple fake transfers.
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :param Integer count:
+            The number of share transfers to be faked
+        :return:
+            A list of FakeResource objects
+        """
+
+        share_transfers = []
+        for n in range(0, count):
+            share_transfers.append(
+                FakeShareSnapshot.create_one_snapshot(attrs))
+
+        return share_transfers
+
+
 class FakeSnapshotAccessRule(object):
     """Fake one or more snapshot access rules"""
 
@@ -920,6 +983,7 @@ class FakeShareSecurityService(object):
             "password": 'password',
             "project_id": uuid.uuid4().hex,
             "server": 'fake_hostname',
+            "default_ad_site": 'fake_default_ad_site',
             "status": 'new',
             "type": 'ldap',
             "updated_at": datetime.datetime.now().isoformat(),
@@ -1191,6 +1255,7 @@ class FakeShareNetworkSubnet(object):
             "share_network_id": str(uuid.uuid4()),
             "share_network_name": str(uuid.uuid4()),
             "updated_at": datetime.datetime.now().isoformat(),
+            "properties": {},
         }
 
         share_network_subnet.update(attrs)
@@ -1431,6 +1496,7 @@ class FakeShareServer(object):
             'share_network_name': None,
             'share_network_id': str(uuid.uuid4()),
             'share_network_subnet_id': str(uuid.uuid4()),
+            'source_share_server_id': str(uuid.uuid4()),
             'created_at': datetime.datetime.now().isoformat(),
             'is_auto_deletable': False,
             'identifier': str(uuid.uuid4())
@@ -1460,3 +1526,119 @@ class FakeShareServer(object):
             share_servers.append(
                 FakeShareServer.create_one_server(attrs))
         return share_servers
+
+
+class FakeResourceLock(object):
+    """Fake a resource lock"""
+
+    @staticmethod
+    def create_one_lock(attrs=None, methods=None):
+        """Create a fake resource lock
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :return:
+            A FakeResource object, with id, resource and so on
+        """
+
+        attrs = attrs or {}
+        methods = methods or {}
+        now_time = datetime.datetime.now()
+        delta_time = now_time + datetime.timedelta(minutes=5)
+
+        lock = {
+            'id': str(uuid.uuid4()),
+            'resource_id': str(uuid.uuid4()),
+            'resource_type': 'share',
+            'resource_action': 'delete',
+            'created_at': now_time.isoformat(),
+            'updated_at': delta_time.isoformat(),
+            'project_id': uuid.uuid4().hex,
+            'user_id': uuid.uuid4().hex,
+            'lock_context': 'user',
+            'lock_reason': 'created by func tests',
+        }
+
+        lock.update(attrs)
+        lock = osc_fakes.FakeResource(info=copy.deepcopy(
+            lock),
+            methods=methods,
+            loaded=True)
+        return lock
+
+    @staticmethod
+    def create_locks(attrs=None, count=2):
+        """Create multiple fake locks.
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :param Integer count:
+            The number of share transfers to be faked
+        :return:
+            A list of FakeResource objects
+        """
+
+        resource_locks = []
+        for n in range(0, count):
+            resource_locks.append(
+                FakeResourceLock.create_one_lock(attrs))
+
+        return resource_locks
+
+
+class FakeShareBackup(object):
+    """Fake a share Backup"""
+
+    @staticmethod
+    def create_one_backup(attrs=None, methods=None):
+        """Create a fake share backup
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :return:
+            A FakeResource object, with project_id, resource and so on
+        """
+
+        attrs = attrs or {}
+        methods = methods or {}
+
+        share_backup = {
+            'id': 'backup-id-' + uuid.uuid4().hex,
+            'share_id': 'share-id-' + uuid.uuid4().hex,
+            'status': None,
+            'name': None,
+            'description': None,
+            'size': '0',
+            'created_at': datetime.datetime.now().isoformat(),
+            'updated_at': datetime.datetime.now().isoformat(),
+            'availability_zone': None,
+            'progress': None,
+            'restore_progress': None,
+            'host': None,
+            'topic': None,
+        }
+
+        share_backup.update(attrs)
+        share_backup = osc_fakes.FakeResource(info=copy.deepcopy(
+            share_backup),
+            methods=methods,
+            loaded=True)
+        return share_backup
+
+    @staticmethod
+    def create_share_backups(attrs=None, count=2):
+        """Create multiple fake backups.
+
+        :param Dictionary attrs:
+            A dictionary with all attributes
+        :param Integer count:
+            The number of share backups to be faked
+        :return:
+            A list of FakeResource objects
+        """
+
+        share_backups = []
+        for n in range(0, count):
+            share_backups.append(
+                FakeShareBackup.create_one_backup(attrs))
+        return share_backups
