@@ -13,7 +13,6 @@
 #   under the License.
 #
 
-import argparse
 import ddt
 from unittest import mock
 import uuid
@@ -70,6 +69,14 @@ class TestShare(manila_fakes.TestShare):
             0)
         return shares
 
+    def setup_share_groups_mock(self):
+        self.share_group_mock = self.app.client_manager.share.share_groups
+        self.share_group_mock.reset_mock()
+
+        share_group = manila_fakes.FakeShareGroup.create_one_share_group()
+        self.share_group_mock.get = mock.Mock(return_value=share_group)
+        return share_group
+
 
 @ddt.ddt
 class TestShareCreate(TestShare):
@@ -124,7 +131,8 @@ class TestShareCreate(TestShare):
             share_type=self.share_type.id,
             size=self.new_share.size,
             snapshot_id=None,
-            scheduler_hints={}
+            scheduler_hints={},
+            mount_point_name=None,
         )
 
         self.assertCountEqual(self.columns, columns)
@@ -172,7 +180,8 @@ class TestShareCreate(TestShare):
             share_type=self.share_type.id,
             size=self.new_share.size,
             snapshot_id=None,
-            scheduler_hints={}
+            scheduler_hints={},
+            mount_point_name=None,
         )
 
         self.assertCountEqual(self.columns, columns)
@@ -219,6 +228,49 @@ class TestShareCreate(TestShare):
             snapshot_id=None,
             scheduler_hints={'same_host': shares[0].id,
                              'different_host': shares[1].id},
+            mount_point_name=None,
+        )
+
+        self.assertCountEqual(self.columns, columns)
+        self.assertCountEqual(self.datalist, data)
+
+    def test_share_create_mount_point_name(self):
+        """Verifies that the mount point name has been passed correctly."""
+        self.app.client_manager.share.api_version = api_versions.APIVersion(
+            "2.84")
+
+        mount_point_name = "fake_mp"
+
+        arglist = [
+            self.new_share.share_proto,
+            str(self.new_share.size),
+            '--share-type', self.share_type.id,
+            '--mount-point-name', mount_point_name,
+        ]
+        verifylist = [
+            ('share_proto', self.new_share.share_proto),
+            ('size', self.new_share.size),
+            ('mount_point_name', mount_point_name),
+            ('share_type', self.share_type.id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.shares_mock.create.assert_called_with(
+            availability_zone=None,
+            description=None,
+            is_public=False,
+            metadata={},
+            name=None,
+            share_group_id=None,
+            share_network=None,
+            share_proto=self.new_share.share_proto,
+            share_type=self.share_type.id,
+            size=self.new_share.size,
+            snapshot_id=None,
+            scheduler_hints={},
+            mount_point_name='fake_mp',
         )
 
         self.assertCountEqual(self.columns, columns)
@@ -261,7 +313,8 @@ class TestShareCreate(TestShare):
             share_type=None,
             size=self.new_share.size,
             snapshot_id=self.share_snapshot.id,
-            scheduler_hints={}
+            scheduler_hints={},
+            mount_point_name=None,
         )
         self.assertCountEqual(self.columns, columns)
         self.assertCountEqual(self.datalist, data)
@@ -297,7 +350,8 @@ class TestShareCreate(TestShare):
             share_type=self.share_type.id,
             size=self.new_share.size,
             snapshot_id=None,
-            scheduler_hints={}
+            scheduler_hints={},
+            mount_point_name=None,
         )
 
         self.shares_mock.get.assert_called_with(self.new_share.id)
@@ -337,7 +391,8 @@ class TestShareCreate(TestShare):
                 share_type=self.share_type.id,
                 size=self.new_share.size,
                 snapshot_id=None,
-                scheduler_hints={}
+                scheduler_hints={},
+                mount_point_name=None,
             )
 
             mock_logger.error.assert_called_with(
@@ -364,6 +419,8 @@ class TestShareCreate(TestShare):
             osc_exceptions.CommandError,
             self.cmd.take_action,
             parsed_args)
+        self.share_types_mock.get.assert_called_once_with(
+            share_type='default')
 
     @ddt.data('None', 'NONE', 'none')
     def test_create_share_with_the_name_none(self, name):
@@ -415,6 +472,8 @@ class TestShareDelete(TestShare):
 
         result = self.cmd.take_action(parsed_args)
         self.shares_mock.delete.assert_called_with(shares[0], None)
+        self.shares_mock.soft_delete.assert_not_called()
+        self.shares_mock.force_delete.assert_not_called()
         self.assertIsNone(result)
 
     def test_share_delete_many(self):
@@ -434,6 +493,26 @@ class TestShareDelete(TestShare):
         self.shares_mock.delete.assert_has_calls(calls)
         self.assertIsNone(result)
 
+    def test_share_delete_with_share_group(self):
+        shares = self.setup_shares_mock(count=1)
+        share_group = self.setup_share_groups_mock()
+
+        arglist = [
+            shares[0].name,
+            '--share-group', share_group['id']
+        ]
+        verifylist = [
+            ("share_group", share_group['id']),
+            ('shares', [shares[0].name])
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        result = self.cmd.take_action(parsed_args)
+        self.shares_mock.delete.assert_called_with(
+            shares[0], share_group['id'])
+        self.assertIsNone(result)
+
     def test_share_delete_with_force(self):
         shares = self.setup_shares_mock(count=1)
 
@@ -451,6 +530,8 @@ class TestShareDelete(TestShare):
         result = self.cmd.take_action(parsed_args)
 
         self.shares_mock.force_delete.assert_called_once_with(shares[0])
+        self.shares_mock.delete.assert_not_called()
+        self.shares_mock.soft_delete.assert_not_called()
         self.assertIsNone(result)
 
     def test_share_delete_with_soft(self):
@@ -470,6 +551,8 @@ class TestShareDelete(TestShare):
         result = self.cmd.take_action(parsed_args)
 
         self.shares_mock.soft_delete.assert_called_once_with(shares[0])
+        self.shares_mock.delete.assert_not_called()
+        self.shares_mock.force_delete.assert_not_called()
         self.assertIsNone(result)
 
     def test_share_delete_wrong_name(self):
@@ -968,7 +1051,7 @@ class TestShareList(TestShare):
         verifylist = [
             ("limit", -2),
         ]
-        self.assertRaises(argparse.ArgumentTypeError, self.check_parser,
+        self.assertRaises(osc_utils.ParserException, self.check_parser,
                           self.cmd, arglist, verifylist)
 
     def test_share_list_name_description_filter(self):
@@ -1070,12 +1153,11 @@ class TestShareShow(TestShare):
         self.shares_mock.get.assert_called_with(self._share.id)
 
         self.assertEqual(
-            manila_fakes.FakeShare.get_share_columns(self._share),
-            columns)
+            sorted(manila_fakes.FakeShare.get_share_columns(self._share)),
+            sorted(columns))
 
-        self.assertEqual(
-            manila_fakes.FakeShare.get_share_data(self._share),
-            data)
+        self.assertCountEqual(
+            manila_fakes.FakeShare.get_share_data(self._share), data)
 
 
 class TestShareSet(TestShare):
@@ -1084,7 +1166,8 @@ class TestShareSet(TestShare):
         super(TestShareSet, self).setUp()
 
         self._share = manila_fakes.FakeShare.create_one_share(
-            methods={"reset_state": None, "reset_task_state": None}
+            methods={"reset_state": None, "reset_task_state": None,
+                     "set_metadata": None}
         )
         self.shares_mock.get.return_value = self._share
 
@@ -1104,8 +1187,7 @@ class TestShareSet(TestShare):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         self.cmd.take_action(parsed_args)
-        self.shares_mock.set_metadata.assert_called_with(
-            self._share.id,
+        self._share.set_metadata.assert_called_with(
             {'Zorilla': 'manila'})
 
     def test_share_set_name(self):
@@ -1196,13 +1278,12 @@ class TestShareSet(TestShare):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         self.cmd.take_action(parsed_args)
-        self.shares_mock.set_metadata.assert_called_with(
-            self._share.id,
+        self._share.set_metadata.assert_called_with(
             {'key': ''})
 
         # '--property' takes key=value arguments
         # missing a value would raise a BadRequest
-        self.shares_mock.set_metadata.side_effect = exceptions.BadRequest()
+        self._share.set_metadata.side_effect = exceptions.BadRequest
         self.assertRaises(
             osc_exceptions.CommandError, self.cmd.take_action, parsed_args)
 
@@ -1262,7 +1343,9 @@ class TestShareUnset(TestShare):
     def setUp(self):
         super(TestShareUnset, self).setUp()
 
-        self._share = manila_fakes.FakeShare.create_one_share()
+        self._share = manila_fakes.FakeShare.create_one_share(
+            methods={"delete_metadata": None}
+        )
         self.shares_mock.get.return_value = self._share
 
         # Get the command objects to test
@@ -1281,8 +1364,7 @@ class TestShareUnset(TestShare):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         self.cmd.take_action(parsed_args)
-        self.shares_mock.delete_metadata.assert_called_with(
-            self._share.id,
+        self._share.delete_metadata.assert_called_with(
             parsed_args.property)
 
     def test_share_unset_name(self):
@@ -1348,12 +1430,11 @@ class TestShareUnset(TestShare):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         self.cmd.take_action(parsed_args)
-        self.shares_mock.delete_metadata.assert_called_with(
-            self._share.id,
+        self._share.delete_metadata.assert_called_with(
             parsed_args.property)
 
         # 404 Not Found would be raised, if property 'Manila' doesn't exist
-        self.shares_mock.delete_metadata.side_effect = exceptions.NotFound()
+        self._share.delete_metadata.side_effect = exceptions.NotFound
         self.assertRaises(
             osc_exceptions.CommandError, self.cmd.take_action, parsed_args)
 
@@ -1827,6 +1908,148 @@ class TestShareExportLocationList(TestShare):
         self.assertCountEqual(self.values, data)
 
 
+class TestExportLocationSet(TestShare):
+
+    def setUp(self):
+        super(TestExportLocationSet, self).setUp()
+
+        self._share = manila_fakes.FakeShare.create_one_share(
+            methods={"set_metadata": None}
+        )
+        self.shares_mock.get.return_value = self._share
+
+        self._export_location = (
+            manila_fakes.FakeShareExportLocation.create_one_export_location(
+                {'fake_share_instance_id': self._share.id}))
+
+        self.export_locations_mock.get.return_value = (
+            self._export_location
+        )
+
+        self.cmd = osc_shares.ShareExportLocationSet(self.app, None)
+
+    def test_share_set_export_location_property(self):
+        self.app.client_manager.share.api_version = api_versions.APIVersion(
+            '2.87'
+        )
+        arglist = [
+            self._share.id,
+            self._export_location.id,
+            '--property', 'Bobcat=manila',
+
+        ]
+        verifylist = [
+            ('share', self._share.id),
+            ('export_location', self._export_location.id),
+            ('property', {'Bobcat': 'manila'}),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.cmd.take_action(parsed_args)
+        self.export_locations_mock.set_metadata.assert_called_once_with(
+            self._share.id, {'Bobcat': 'manila'},
+            subresource=self._export_location.id)
+
+    def test_share_set_export_location_property_exception(self):
+        self.app.client_manager.share.api_version = api_versions.APIVersion(
+            '2.87'
+        )
+        arglist = [
+            self._share.id,
+            self._export_location.id,
+            '--property', 'key=',
+        ]
+        verifylist = [
+            ('share', self._share.id),
+            ('export_location', self._export_location.id),
+            ('property', {'key': ''}),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.cmd.take_action(parsed_args)
+
+        self.export_locations_mock.set_metadata.assert_called_once_with(
+            self._share.id, {'key': ''},
+            subresource=self._export_location.id)
+
+        self.export_locations_mock.set_metadata.side_effect = (
+            exceptions.BadRequest)
+        self.assertRaises(
+            osc_exceptions.CommandError, self.cmd.take_action,
+            parsed_args)
+
+
+class TestExportLocationUnset(TestShare):
+
+    def setUp(self):
+        super(TestExportLocationUnset, self).setUp()
+
+        self._share = manila_fakes.FakeShare.create_one_share(
+            methods={"set_metadata": None}
+        )
+        self.shares_mock.get.return_value = self._share
+
+        self._export_location = (
+            manila_fakes.FakeShareExportLocation.create_one_export_location(
+                {'fake_share_instance_id': self._share.id}))
+
+        self.export_locations_mock.get.return_value = (
+            self._export_location
+        )
+
+        self.cmd = osc_shares.ShareExportLocationUnset(self.app, None)
+
+    def test_share_unset_export_location_property(self):
+        self.app.client_manager.share.api_version = api_versions.APIVersion(
+            '2.87'
+        )
+        arglist = [
+            self._share.id,
+            self._export_location.id,
+            '--property', 'Bobcat',
+
+        ]
+        verifylist = [
+            ('share', self._share.id),
+            ('export_location', self._export_location.id),
+            ('property', ['Bobcat']),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.cmd.take_action(parsed_args)
+        self.export_locations_mock.delete_metadata.assert_called_once_with(
+            self._share.id, ['Bobcat'],
+            subresource=self._export_location.id)
+
+    def test_share_unset_export_location_property_exception(self):
+        self.app.client_manager.share.api_version = api_versions.APIVersion(
+            '2.87'
+        )
+        arglist = [
+            self._share.id,
+            self._export_location.id,
+            '--property', 'key',
+        ]
+        verifylist = [
+            ('share', self._share.id),
+            ('export_location', self._export_location.id),
+            ('property', ['key']),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.cmd.take_action(parsed_args)
+
+        self.export_locations_mock.delete_metadata.assert_has_calls([
+            mock.call(self._share.id, ['key'],
+                      subresource=self._export_location.id)])
+
+        self.export_locations_mock.delete_metadata.side_effect = (
+            exceptions.NotFound)
+        self.assertRaises(
+            osc_exceptions.CommandError, self.cmd.take_action,
+            parsed_args)
+
+
 class TestShowShareProperties(TestShare):
 
     properties = {
@@ -1841,7 +2064,8 @@ class TestShowShareProperties(TestShare):
             attrs={
                 'metadata': osc_fakes.FakeResource(
                     info=self.properties)
-            }
+            },
+            methods={'get_metadata': None}
         )
         self.shares_mock.get.return_value = self._share
         self.shares_mock.get_metadata.return_value = self._share.metadata
