@@ -50,7 +50,7 @@ class SharesTest(utils.TestCase):
         self.share.allow(access_type, access_to, access_level)
 
         self.share.manager.allow.assert_called_once_with(
-            self.share, access_type, access_to, access_level, None)
+            self.share, access_type, access_to, access_level)
 
     # Testcases for class ShareManager
 
@@ -140,6 +140,29 @@ class SharesTest(utils.TestCase):
                          availability_zone=availability_zone)
         cs.assert_called('POST', '/shares', body)
 
+    @ddt.data({'mount_point_name': 'fake_mount_pt1'},
+              {'mount_point_name': 'fake_mount_pt2'})
+    @ddt.unpack
+    def test_create_share_with_mount_point_name(self, mount_point_name):
+        body = {
+            'share': {
+                'is_public': False,
+                'share_type': None,
+                'name': None,
+                'snapshot_id': None,
+                'description': None,
+                'metadata': {},
+                'share_proto': 'nfs',
+                'share_network_id': None,
+                'size': 1,
+                'availability_zone': None,
+                'scheduler_hints': {},
+                'mount_point_name': mount_point_name,
+            }
+        }
+        cs.shares.create('nfs', 1, mount_point_name=mount_point_name)
+        cs.assert_called('POST', '/shares', body)
+
     @ddt.data(
         type('ShareUUID', (object, ), {'uuid': '1234'}),
         type('ShareID', (object, ), {'id': '1234'}),
@@ -398,7 +421,7 @@ class SharesTest(utils.TestCase):
         cs.assert_called(
             'GET', '/shares/detail?is_public=True&with_count=True')
         self.assertEqual(2, count)
-        self.assertEqual(1, len(shares))
+        self.assertEqual(4, len(shares))
 
     def test_list_shares_detailed_with_count(self):
         cs.shares.list(detailed=True)
