@@ -15,16 +15,16 @@
 
 from manilaclient import api_versions
 from manilaclient import base
-from manilaclient.common.apiclient import base as common_base
 from manilaclient import exceptions
 
 RESOURCES_PATH = '/share-networks'
 RESOURCE_PATH = "/share-networks/%s"
 RESOURCE_NAME = 'share_network'
 RESOURCES_NAME = 'share_networks'
+ACTION_PATH = RESOURCE_PATH + '/action'
 
 
-class ShareNetwork(common_base.Resource):
+class ShareNetwork(base.Resource):
     """Network info for Manila shares."""
     def __repr__(self):
         return "<ShareNetwork: %s>" % self.id
@@ -115,24 +115,6 @@ class ShareNetworkManager(base.ManagerWithFind):
 
         return self._create(RESOURCES_PATH, body, RESOURCE_NAME)
 
-    def add_security_service(self, share_network, security_service):
-        """Associate given security service with a share network.
-
-        :param share_network: share network name, id or ShareNetwork instance
-        :param security_service: name, id or SecurityService instance
-        :rtype: :class:`ShareNetwork`
-        """
-        body = {
-            'add_security_service': {
-                'security_service_id': common_base.getid(security_service),
-            },
-        }
-        return self._create(
-            RESOURCE_PATH % common_base.getid(share_network) + '/action',
-            body,
-            RESOURCE_NAME,
-        )
-
     def remove_security_service(self, share_network, security_service):
         """Dissociate security service from a share network.
 
@@ -142,11 +124,11 @@ class ShareNetworkManager(base.ManagerWithFind):
         """
         body = {
             'remove_security_service': {
-                'security_service_id': common_base.getid(security_service),
+                'security_service_id': base.getid(security_service),
             },
         }
         return self._create(
-            RESOURCE_PATH % common_base.getid(share_network) + '/action',
+            RESOURCE_PATH % base.getid(share_network) + '/action',
             body,
             RESOURCE_NAME,
         )
@@ -157,7 +139,7 @@ class ShareNetworkManager(base.ManagerWithFind):
         :param policy: share network to get.
         :rtype: :class:`NetworkInfo`
         """
-        return self._get(RESOURCE_PATH % common_base.getid(share_network),
+        return self._get(RESOURCE_PATH % base.getid(share_network),
                          RESOURCE_NAME)
 
     @api_versions.wraps("1.0", "2.25")
@@ -190,7 +172,7 @@ class ShareNetworkManager(base.ManagerWithFind):
             raise exceptions.CommandError(msg)
 
         body = {RESOURCE_NAME: values}
-        return self._update(RESOURCE_PATH % common_base.getid(share_network),
+        return self._update(RESOURCE_PATH % base.getid(share_network),
                             body,
                             RESOURCE_NAME)
 
@@ -222,7 +204,7 @@ class ShareNetworkManager(base.ManagerWithFind):
             raise exceptions.CommandError(msg)
 
         body = {RESOURCE_NAME: values}
-        return self._update(RESOURCE_PATH % common_base.getid(share_network),
+        return self._update(RESOURCE_PATH % base.getid(share_network),
                             body,
                             RESOURCE_NAME)
 
@@ -231,7 +213,7 @@ class ShareNetworkManager(base.ManagerWithFind):
 
         :param share_network: share network to be deleted.
         """
-        self._delete(RESOURCE_PATH % common_base.getid(share_network))
+        self._delete(RESOURCE_PATH % base.getid(share_network))
 
     def list(self, detailed=True, search_opts=None):
         """Get a list of all share network.
@@ -246,3 +228,123 @@ class ShareNetworkManager(base.ManagerWithFind):
             path = RESOURCES_PATH + query_string
 
         return self._list(path, RESOURCES_NAME)
+
+    def _action(self, action, share_network, info=None):
+        """Perform a share network 'action'.
+
+        :param action: text with action name.
+        :param share_network: either share_network object or text with its ID.
+        :param info: dict with data for specified 'action'.
+        """
+        body = {action: info}
+        self.run_hooks('modify_body_for_action', body)
+        url = ACTION_PATH % base.getid(share_network)
+        return self.api.client.post(url, body=body)
+
+    def add_security_service(self, share_network, security_service):
+        """Associate given security service with a share network.
+
+        :param share_network: share network name, id or ShareNetwork instance
+        :param security_service: name, id or SecurityService instance
+        :rtype: :class:`ShareNetwork`
+        """
+        info = {
+            'security_service_id': base.getid(security_service),
+        }
+        return self._action('add_security_service', share_network, info)
+
+    @api_versions.wraps("2.63")
+    def add_security_service_check(self, share_network, security_service,
+                                   reset_operation=False):
+        """Associate given security service with a share network.
+
+        :param share_network: share network name, id or ShareNetwork instance
+        :param security_service: name, id or SecurityService instance
+        :param reset_operation: start over the check operation
+        :rtype: :class:`ShareNetwork`
+        """
+        info = {
+            'security_service_id': base.getid(security_service),
+            'reset_operation': reset_operation,
+        }
+        return self._action('add_security_service_check', share_network, info)
+
+    @api_versions.wraps("2.63")
+    def update_share_network_security_service(self, share_network,
+                                              current_security_service,
+                                              new_security_service):
+        """Update current security service to new one of a given share network.
+
+        :param share_network: share network name, id or ShareNetwork instance
+        :param current_security_service: current name, id or
+        SecurityService instance that will be changed
+        :param new_security_service: new name, id or
+        SecurityService instance that will be updated
+        :rtype: :class:`ShareNetwork`
+        """
+        info = {
+            'current_service_id': base.getid(current_security_service),
+            'new_service_id': base.getid(new_security_service)}
+
+        return self._action('update_security_service', share_network, info)
+
+    @api_versions.wraps("2.63")
+    def update_share_network_security_service_check(
+            self, share_network, current_security_service,
+            new_security_service, reset_operation=False):
+        """Validates if the security service update is supported by all hosts.
+
+        :param share_network: share network name, id or ShareNetwork instance
+        :param current_security_service: current name, id or
+        SecurityService instance that will be changed
+        :param new_security_service: new name, id or
+        :param reset_operation: start over the check operation
+        SecurityService instance that will be updated
+        :rtype: :class:`ShareNetwork`
+        """
+        info = {
+            'current_service_id': base.getid(current_security_service),
+            'new_service_id': base.getid(new_security_service),
+            'reset_operation': reset_operation
+        }
+
+        return self._action('update_security_service_check',
+                            share_network, info)
+
+    @api_versions.wraps("2.63")
+    def reset_state(self, share_network, state):
+        """Reset state of a share network.
+
+        :param share_network: either share_network object or text with its ID
+        or name.
+        :param state: text with new state to set for share network.
+        """
+        return self._action('reset_status', share_network,
+                            {"status": state})
+
+    @api_versions.wraps("2.70")
+    def share_network_subnet_create_check(self, share_network_id,
+                                          neutron_net_id=None,
+                                          neutron_subnet_id=None,
+                                          availability_zone=None,
+                                          reset_operation=False):
+        """Check if share network subnet can be created in given share network.
+
+        :param share_network_id: ID of the Share network
+        :param neutron_net_id: ID of Neutron network
+        :param neutron_subnet_id: ID of Neutron subnet
+        :param availability_zone: Name of the target availability zone
+        :param reset_operation: Start over the check operation
+        :rtype: :class:`ShareNetworkSubnet`
+        """
+        values = {}
+        if neutron_net_id:
+            values['neutron_net_id'] = neutron_net_id
+        if neutron_subnet_id:
+            values['neutron_subnet_id'] = neutron_subnet_id
+        if availability_zone:
+            values['availability_zone'] = availability_zone
+        values['reset_operation'] = reset_operation
+
+        return self._action('share_network_subnet_create_check',
+                            share_network_id, values)
