@@ -27,7 +27,8 @@ from manilaclient import exceptions
 from manilaclient.v2 import share_instances
 
 
-class Share(base.Resource):
+class Share(base.MetadataCapableResource):
+
     """A share is an extra block level storage to the OpenStack instances."""
     def __repr__(self):
         return "<Share: %s>" % self.id
@@ -74,23 +75,18 @@ class Share(base.Resource):
         """Delete the specified share ignoring its current state."""
         self.manager.force_delete(self)
 
-    def allow(self, access_type, access, access_level, metadata=None):
+    def allow(self, *args, **kwargs):
         """Allow access to a share."""
-        return self.manager.allow(
-            self, access_type, access, access_level, metadata)
+        return self.manager.allow(self, *args, **kwargs)
 
-    def deny(self, id):
+    def deny(self, id, **kwargs):
         """Deny access from IP to a share."""
-        return self.manager.deny(self, id)
+        return self.manager.deny(self, id, **kwargs)
 
     def access_list(self):
         """Get access list from a share."""
         return self.manager.access_list(self)
 
-    def update_all_metadata(self, metadata):
-        """Update all metadata of this share."""
-        return self.manager.update_all_metadata(self, metadata)
-
     def reset_state(self, state):
         """Update the share with the provided state."""
         self.manager.reset_state(self, state)
@@ -120,14 +116,16 @@ class Share(base.Resource):
         self.manager.restore(self)
 
 
-class ShareManager(base.ManagerWithFind):
+class ShareManager(base.MetadataCapableManager):
     """Manage :class:`Share` resources."""
     resource_class = Share
+    resource_path = '/shares'
 
     def create(self, share_proto, size, snapshot_id=None, name=None,
                description=None, metadata=None, share_network=None,
                share_type=None, is_public=False, availability_zone=None,
-               share_group_id=None, scheduler_hints=None, return_raw=False):
+               share_group_id=None, scheduler_hints=None, return_raw=False,
+               mount_point_name=None):
         """Create a share.
 
         :param share_proto: text - share protocol for new share available
@@ -145,6 +143,9 @@ class ShareManager(base.ManagerWithFind):
         :param scheduler_hints: dict - hints for the scheduler to place share
             on most appropriate host e.g. keys are same_host for affinity and
             different_host for anti-affinity
+        :param mount_point_name: text - share human-readable mount point name.
+            This name will be reflected in export location once
+            share is created.
         :rtype: :class:`Share`
         """
         share_metadata = metadata if metadata is not None else dict()
@@ -166,6 +167,9 @@ class ShareManager(base.ManagerWithFind):
         if share_group_id:
             body['share_group_id'] = share_group_id
 
+        if mount_point_name:
+            body['mount_point_name'] = mount_point_name
+
         return self._create('/shares', {'share': body}, 'share',
                             return_raw=return_raw)
 
@@ -360,6 +364,8 @@ class ShareManager(base.ManagerWithFind):
     def list(self, detailed=True, search_opts=None,   # noqa
              sort_key=None, sort_dir=None, return_raw=False):
         """Get a list of all shares."""
+        if search_opts is None:
+            search_opts = {}
         search_opts.pop("is_soft_deleted", None)
         return self.do_list(detailed=detailed, search_opts=search_opts,
                             sort_key=sort_key, sort_dir=sort_dir,
@@ -572,7 +578,8 @@ class ShareManager(base.ManagerWithFind):
             raise exceptions.CommandError(msg)
 
     def _do_allow(self, share, access_type, access, access_level, action_name,
-                  metadata=None):
+                  metadata=None, lock_visibility=False,
+                  lock_deletion=False, lock_reason=None):
         """Allow access to a share.
 
         :param share: either share object or text with its ID.
@@ -589,6 +596,12 @@ class ShareManager(base.ManagerWithFind):
             access_params['access_level'] = access_level
         if metadata:
             access_params['metadata'] = metadata
+        if lock_visibility:
+            access_params['lock_visibility'] = lock_visibility
+        if lock_deletion:
+            access_params['lock_deletion'] = lock_deletion
+        if lock_reason:
+            access_params['lock_reason'] = lock_reason
         access = self._action(action_name, share,
                               access_params)[1]["access"]
         return access
@@ -620,30 +633,53 @@ class ShareManager(base.ManagerWithFind):
         return self._do_allow(
             share, access_type, access, access_level, "allow_access")
 
-    @api_versions.wraps("2.45")  # noqa
+    @api_versions.wraps("2.45", "2.81")  # noqa
     def allow(self, share, access_type, access, access_level, metadata=None):   # noqa
         valid_access_types = ('ip', 'user', 'cert', 'cephx')
         self._validate_access(access_type, access, valid_access_types,
                               enable_ipv6=True)
         return self._do_allow(
-            share, access_type, access, access_level, "allow_access", metadata)
+            share, access_type, access, access_level, "allow_access",
+            metadata=metadata)
 
-    def _do_deny(self, share, access_id, action_name):
+    @api_versions.wraps("2.82")  # noqa
+    def allow(self, share, access_type, access, access_level, # pylint: disable=function-redefined  # noqa F811
+              metadata=None, lock_visibility=False, lock_deletion=False,
+              lock_reason=None):
+        valid_access_types = ('ip', 'user', 'cert', 'cephx')
+        self._validate_access(access_type, access, valid_access_types,
+                              enable_ipv6=True)
+        return self._do_allow(
+            share, access_type, access, access_level, "allow_access",
+            metadata=metadata, lock_visibility=lock_visibility,
+            lock_deletion=lock_deletion, lock_reason=lock_reason)
+
+    def _do_deny(self, share, access_id, action_name, unrestrict=False):
         """Deny access to a share.
 
         :param share: either share object or text with its ID.
         :param access_id: ID of share access rule
         """
-        return self._action(action_name, share, {"access_id": access_id})
+        body = {
+            "access_id": access_id,
+        }
+        if unrestrict:
+            body['unrestrict'] = True
+        return self._action(action_name, share, body)
 
     @api_versions.wraps("1.0", "2.6")
     def deny(self, share, access_id):
         return self._do_deny(share, access_id, "os-deny_access")
 
-    @api_versions.wraps("2.7")  # noqa
+    @api_versions.wraps("2.7", "2.81")  # noqa
     def deny(self, share, access_id):   # noqa
         return self._do_deny(share, access_id, "deny_access")
 
+    @api_versions.wraps("2.82")  # noqa
+    def deny(self, share, access_id, unrestrict=False):  # noqa
+        return self._do_deny(share, access_id, "deny_access",
+                             unrestrict=unrestrict)
+
     def _do_access_list(self, share, action_name):
         """Get access list to a share.
 
@@ -664,45 +700,6 @@ class ShareManager(base.ManagerWithFind):
     def access_list(self, share):   # noqa
         return self._do_access_list(share, "access_list")
 
-    def get_metadata(self, share):
-        """Get metadata of a share.
-
-        :param share: either share object or text with its ID.
-        """
-        return self._get("/shares/%s/metadata" % base.getid(share),
-                         "metadata")
-
-    def set_metadata(self, share, metadata):
-        """Set or update metadata for share.
-
-        :param share: either share object or text with its ID.
-        :param metadata: A list of keys to be set.
-        """
-        body = {'metadata': metadata}
-        return self._create("/shares/%s/metadata" % base.getid(share),
-                            body, "metadata")
-
-    def delete_metadata(self, share, keys):
-        """Delete specified keys from shares metadata.
-
-        :param share: either share object or text with its ID.
-        :param keys: A list of keys to be removed.
-        """
-        share_id = base.getid(share)
-        for key in keys:
-            self._delete("/shares/%(share_id)s/metadata/%(key)s" % {
-                'share_id': share_id, 'key': key})
-
-    def update_all_metadata(self, share, metadata):
-        """Update all metadata of a share.
-
-        :param share: either share object or text with its ID.
-        :param metadata: A list of keys to be updated.
-        """
-        body = {'metadata': metadata}
-        return self._update("/shares/%s/metadata" % base.getid(share),
-                            body)
-
     def _action(self, action, share, info=None, **kwargs):
         """Perform a share 'action'.
 
